Entry

Enum Entry 

pub enum Entry {
    // some variants omitted
}
Entry ::= (Message line_end) | (Term line_end) | CommentLine

Entries are the main building blocks of Fluent.

They define translations and contextual and semantic information about the translations. During the AST construction, adjacent comment lines of the same comment type (defined by the number of #) are joined together. Single-# comments directly preceding Messages and Terms are attached to the Message or Term and are not standalone Entries.