pub struct SelectExpression { /* private fields */ }Expand description
SelectExpression ::= InlineExpression blank? “->” blank_inline? variant_list
Implementations
Sourceimpl SelectExpression
impl SelectExpression
Sourcepub fn new(
inline_expression: InlineExpression,
variant_list: VariantList,
) -> Self
pub fn new( inline_expression: InlineExpression, variant_list: VariantList, ) -> Self
Constructs a new SelectExpression representing a plural/category selection in Fluent.
Arguments
inline_expression- The selector expression whose value determines which variant is chosen.variant_list- The list of variants, including exactly one default variant.
Sourcepub fn inline_expression(&self) -> &InlineExpression
pub fn inline_expression(&self) -> &InlineExpression
Returns a reference to the selector expression of this select expression.